summaryrefslogtreecommitdiff
path: root/muse2/muse/song.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'muse2/muse/song.cpp')
-rw-r--r--muse2/muse/song.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/muse2/muse/song.cpp b/muse2/muse/song.cpp
index 542c6abc..3349686b 100644
--- a/muse2/muse/song.cpp
+++ b/muse2/muse/song.cpp
@@ -2131,7 +2131,7 @@ void Song::clear(bool signal, bool clear_all)
_cycleMode = CYCLE_NORMAL;
_click = false;
_quantize = false;
- _len = 0; // song len in ticks
+ _len = AL::sigmap.bar2tick(150, 0, 0); // default song len in ticks set for 150 bars
_follow = JUMP;
dirty = false;
initDrumMap();